@@ -10,10 +10,33 @@
 import arrow
 import requests
 from edtf import parse_edtf
-from flask import Blueprint
+from flask import Blueprint, render_template
+from invenio_cache import current_cache
 from invenio_rdm_records.vocabularies import Vocabularies
 
 
+def fetch_schemaorg_jsonld(doi_url):
+    """Fetch the Schema.org metadata for the DOI."""
+    key = f"schemaorg_{doi_url}"
+    metadata = current_cache.get(key)
+
+    if metadata is None:
+        try:
+            response = requests.get(
+                doi_url,
+                headers={"Accept": "application/vnd.schemaorg.ld+json"},
+                timeout=2,
+            )
+            if response.status_code == 200:
+                metadata = response.text.strip()
+                curent_cache.set(key, metadata)
+
+        except Exception:
+            pass
+
+    return metadata
+
+
 def create_blueprint(app):
     """Create a blueprint with routes and resources."""
 
@@ -24,25 +47,6 @@ def create_blueprint(app):
         static_folder="static",
     )
 
-    cache = app.extensions["invenio-cache"].cache
-
-    @cache.memoize()
-    def fetch_schemaorg_jsonld(doi_url):
-        metadata = None
-        try:
-            response = requests.get(
-                doi_url,
-                headers={"Accept": "application/vnd.schemaorg.ld+json"},
-                timeout=2,
-            )
-            if response.status_code == 200:
-                metadata = response.text.strip()
-
-        except Exception:
-            pass
-
-        return metadata
-
     @blueprint.app_template_filter("tuw_doi_identifier")
     def tuw_doi_identifier(identifiers):
         """Extract DOI from sequence of identifiers."""
@@ -135,7 +139,8 @@ def create_blueprint(app):
         if "doi" in rec_pids:
             doi = rec_pids["doi"].get("identifier")
         else:
-            doi = tuw_doi_identifier(record.metadata.get("identifiers"))
+            rec_meta = record.get("metadata", {})
+            doi = tuw_doi_identifier(rec_meta.get("identifiers"))
 
         if doi is not None:
             doi_url = (
@@ -144,5 +149,13 @@ def create_blueprint(app):
             metadata = fetch_schemaorg_jsonld(doi_url)
 
         return metadata
+    
+    @blueprint.route('/tuw/policies')
+    def tuw_policies():
+        return render_template('invenio_theme_tuw/policies.html')
+
+    @blueprint.route('/tuw/contact')
+    def tuw_contact():
+        return render_template('invenio_theme_tuw/contact.html')
 
     return blueprint
