@@ -18,9 +18,13 @@ theme = WebpackThemeBundle(
             "entry": {
                 "invenio-theme-tuw-theme": "./less/invenio_theme_tuw/theme.less",
                 "invenio-theme-tuw-tracking": "./js/invenio_theme_tuw/tracking/index.js",
-                "invenio-theme-tuw-planned-features": "./js/invenio_theme_tuw/planned-features/index.js",
+                "invenio-theme-tuw-mobilemenu": "./js/invenio_theme_tuw/mobilemenu/index.js",
+                "invenio-theme-tuw-messages": "./js/invenio_theme_tuw/messages/index.js",
+                "invenio-theme-tuw-pdf-preview": "./js/invenio_theme_tuw/pdf-preview/index.js",
+            },
+            "dependencies": {
+                "jquery": "^3.2.1",
             },
-            "dependencies": {},
         },
     },
 )
